@@ -16,7 +16,8 @@ try:
     import colormap
     from colormap import *
 except ImportError, e:
-    print("colormap module will not work (could not import a package. pylab maybe ?)")
+    pass
+    #print("colormap module will not work (could not import a package. pylab maybe ?)")
 
 import tools
 from tools import *
