@@ -13,7 +13,7 @@
 #  ModelData website: http://www.ebi.ac.uk/~cokelaer/cnolab
 #
 ##############################################################################
-# $Id: package.py 11 2013-02-04 15:37:58Z cokelaer $
+# $Id: package.py 14 2013-02-05 11:20:26Z cokelaer $
 """Utilities for cnolab.wrapper
 
 :author: Thomas Cokelaer <cokelaer@ebi.ac.uk>
@@ -218,7 +218,7 @@ class RPackage(object):
                 self.requirement = False
         except RRuntimeError:
             self.installed = False
-            self.logging.error("Package %s not installedi. Install it from R or with rtools.package.RPackageManager" % self.name)
+            self.logging.error("Package %s not installed. Install it from R or with rtools.package.RPackageManager" % self.name)
         Rwarning(True)
 
     def _get_version(self):
@@ -388,6 +388,7 @@ class RPackageManager(object):
 
         if pkg not in self.packages:
             self.logging.info("Package %s not installed" % pkg)
+            return False
         currentVersion = self.packageVersion(pkg)
         if StrictVersion(currentVersion) >= StrictVersion(version):
             return True
