@@ -4,10 +4,30 @@ Most of the tools in this module are tested indirectly in other modules.
 """
 from rtools.tools import *
 
+# test Rnames2attributes and rcode----------------------------
 
-class Dummy():
-    def __init__(self):
-        pass
+@Rnames2attributes   
+def rcode2():
+    res = rcode("list(a=c(1,2), b=1)")
+    return res
+
+@Rnames2attributes   
+def rcode3():
+    res = rcode("list(a=c(1,2), b=1)")
+    # returns nothing on purpose
+
+def test_rcode():
+    res = rcode("list(a=c(1,2), b=1)")
+
+
+def test_names2attributes():
+    res = rcode2()
+    res.a
+    res.b
+    res = rcode3()
+
+
+# test manual tools ---------------------------------------------------------
 
 def test_RManual():
     d = RManualToDocString("base", "abbreviate")
@@ -15,16 +35,14 @@ def test_RManual():
 
     buildDocString("base","summary")
 
-#@Rnames2attributes   
-#def readMIDAS(file):  
-#    return CNOR.readMIDAS(file)
-
-
-
-#def test_names2attributes():
-#    readMIDAS()
+    buildDocString("base","dummy")
 
 
+#test convertor -------------------------------------------------------
+# used by test_convertor
+class Dummy():
+    def __init__(self):
+        pass
 
 def test_convertor():
     c = RConvertor()
